"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var _react = _interopRequireDefault(require("react"));

var _index = _interopRequireWildcard(require("../index"));

var _reactTestRenderer = require("react-test-renderer");

var _browser = _interopRequireDefault(require("node-blockly/browser"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

jest.mock('node-blockly/browser');
describe('BlocklyDrawerComponent', function () {
  var playground = null;
  var options = {
    createNodeMock: function createNodeMock(element) {
      if (element.type === 'div') {
        return {
          offsetWidth: 10,
          offsetHeight: 15,
          style: {}
        };
      }

      return null;
    }
  };
  beforeEach(function () {
    playground = {
      addChangeListener: jest.fn(function (cb) {
        cb();
      })
    };

    _browser["default"].svgResize.mockReset();

    _browser["default"].inject.mockReset();

    _browser["default"].JavaScript.workspaceToCode.mockReset();

    _browser["default"].Xml.workspaceToDom.mockReset();

    _browser["default"].Xml.domToText.mockReset();

    _browser["default"].inject.mockImplementation(function () {
      return playground;
    });

    _browser["default"].JavaScript.workspaceToCode.mockImplementation(function () {
      return 'test-code';
    });

    _browser["default"].Xml.workspaceToDom.mockImplementation(function () {
      return 'test-xml';
    });

    _browser["default"].Xml.domToText.mockImplementation(function () {
      return 'test-dom-text';
    });

    _browser["default"].Xml.textToDom.mockImplementation(function () {
      return 'test-dom';
    });
  });
  it('renders correctly when no tools nor predefined categories are passed', function () {
    var tree = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], null)).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('renders correctly when predefined categories are passed', function () {
    var comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], null, /*#__PURE__*/_react["default"].createElement(_index.Category, {
      name: "Functions",
      custom: "PROCEDURE"
    })));
    expect(comp.toJSON()).toMatchSnapshot();
  });
  it('renders correctly when tools are passed', function () {
    var comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      tools: [{
        name: 'TestName',
        category: 'TestCategory',
        block: {
          init: function init() {}
        },
        generator: function generator() {}
      }]
    }));
    expect(comp.toJSON()).toMatchSnapshot();
  });
  it('renders correctly when appearance is passed', function () {
    var comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      tools: [{
        name: 'TestName',
        category: 'TestCategory',
        block: {
          init: function init() {}
        },
        generator: function generator() {}
      }],
      appearance: {
        categories: {
          TestCategory: {
            colour: 'blue'
          }
        }
      }
    }));
    expect(comp.toJSON()).toMatchSnapshot();
  });
  it('is initialized correctly', function () {
    var onChange = jest.fn();
    var comp;
    (0, _reactTestRenderer.act)(function () {
      comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
        onChange: onChange
      }), options);
    });
    expect(_browser["default"].inject.mock.calls.length).toBe(1);
    expect(_browser["default"].svgResize.mock.calls.length).toBe(1);
    expect(_browser["default"].JavaScript.workspaceToCode.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.workspaceToDom.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.domToText.mock.calls.length).toBe(1);
    expect(onChange.mock.calls.length).toBe(1);
    expect(_browser["default"].svgResize.mock.calls[0][0]).toBe(playground);
    expect(_browser["default"].JavaScript.workspaceToCode.mock.calls[0][0]).toBe(playground);
    expect(_browser["default"].Xml.workspaceToDom.mock.calls[0][0]).toBe(playground);
    expect(_browser["default"].Xml.domToText.mock.calls[0][0]).toBe('test-xml');
    expect(onChange.mock.calls[0][0]).toBe('test-code');
    expect(onChange.mock.calls[0][1]).toBe('test-dom-text');
    expect(_browser["default"].inject.mock.calls[0][0]).toEqual({
      offsetHeight: 15,
      offsetWidth: 10,
      style: {
        height: '15px',
        width: '10px'
      }
    });
    expect(_browser["default"].inject.mock.calls[0][1]).toEqual({
      toolbox: null
    });
  });
  it('initializes correctly when initial workspace is passed', function () {
    var workspaceXML = '<xml xmlns="http://www.w3.org/1999/xhtml"><variables></variables><block type="HelloWorld" id="gUb!;E2#;hgDD2tP3][/" x="264" y="101"><field name="NAME">sdfsd</field></block></xml>';
    var comp;
    (0, _reactTestRenderer.act)(function () {
      comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
        workspaceXML: workspaceXML
      }), options);
    });
    expect(comp.toJSON()).toMatchSnapshot();
    expect(_browser["default"].Xml.textToDom.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.textToDom.mock.calls[0][0]).toBe(workspaceXML);
    expect(_browser["default"].Xml.domToWorkspace.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.domToWorkspace.mock.calls[0][0]).toBe('test-dom');
    expect(_browser["default"].Xml.domToWorkspace.mock.calls[0][1]).toBe(playground);
  });
  it('passes injectOptions to inject', function () {
    var comp;
    (0, _reactTestRenderer.act)(function () {
      comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
        injectOptions: {
          foo: 42
        }
      }), options);
    });
    expect(_browser["default"].inject.mock.calls[0][1].foo).toBe(42);
  });
  it('allows redefining a language', function () {
    var onChange = jest.fn();
    var mockLanguage = {
      workspaceToCode: jest.fn().mockReturnValue('more-test-code')
    };
    var comp;
    (0, _reactTestRenderer.act)(function () {
      comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
        onChange: onChange,
        language: mockLanguage
      }), options);
    });
    expect(mockLanguage.workspaceToCode.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.workspaceToDom.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.domToText.mock.calls.length).toBe(1);
    expect(onChange.mock.calls.length).toBe(1);
    expect(mockLanguage.workspaceToCode.mock.calls[0][0]).toBe(playground);
    expect(_browser["default"].Xml.workspaceToDom.mock.calls[0][0]).toBe(playground);
    expect(_browser["default"].Xml.domToText.mock.calls[0][0]).toBe('test-xml');
    expect(onChange.mock.calls[0][0]).toBe('more-test-code');
    expect(onChange.mock.calls[0][1]).toBe('test-dom-text');
  });
  it('allows removing a language', function () {
    var onChange = jest.fn();
    var comp;
    (0, _reactTestRenderer.act)(function () {
      comp = (0, _reactTestRenderer.create)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
        onChange: onChange,
        language: null
      }), options);
    });
    expect(_browser["default"].Xml.workspaceToDom.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.domToText.mock.calls.length).toBe(1);
    expect(onChange.mock.calls.length).toBe(1);
    expect(_browser["default"].Xml.workspaceToDom.mock.calls[0][0]).toBe(playground);
    expect(_browser["default"].Xml.domToText.mock.calls[0][0]).toBe('test-xml');
    expect(onChange.mock.calls[0][0]).toBe(null);
    expect(onChange.mock.calls[0][1]).toBe('test-dom-text');
  });
});